@@ -36,7 +36,7 @@ from yapf.yapflib import style
 from yapf.yapflib import verifier
 
 
-def Reformat(uwlines, verify=True):
+def Reformat(uwlines, verify=False):
   """Reformat the unwrapped lines.
 
   Arguments:
@@ -217,8 +217,16 @@ def _CanPlaceOnSingleLine(uwline):
     True if the line can or should be added to a single line. False otherwise.
   """
   indent_amt = style.Get('INDENT_WIDTH') * uwline.depth
-  return (uwline.last.total_length + indent_amt <= style.Get('COLUMN_LIMIT') and
-          not any(tok.is_comment for tok in uwline.tokens[:-1]))
+  last = uwline.last
+  last_index = -1
+  if last.is_comment and re.search(r'^#+\s+pylint:', last.value.strip(),
+                                   re.IGNORECASE):
+    last = last.previous_token
+    last_index = -2
+  if last is None:
+    return True
+  return (last.total_length + indent_amt <= style.Get('COLUMN_LIMIT') and
+          not any(tok.is_comment for tok in uwline.tokens[:last_index]))
 
 
 def _FormatFinalLines(final_lines, verify):
@@ -452,7 +460,7 @@ def _CalculateNumberOfNewlines(first_token, indent_depth, prev_uwline,
     else:
       return ONE_BLANK_LINE
 
-  if first_token.value in {'class', 'def', '@'}:
+  if first_token.value in {'class', 'def', 'async', '@'}:
     # TODO(morbo): This can go once the blank line calculator is more
     # sophisticated.
     if not indent_depth:
@@ -478,7 +486,7 @@ def _CalculateNumberOfNewlines(first_token, indent_depth, prev_uwline,
                                            pytree_utils.Annotation.NEWLINES,
                                            None)
           return NO_BLANK_LINES
-    elif prev_uwline.first.value in {'class', 'def'}:
+    elif prev_uwline.first.value in {'class', 'def', 'async'}:
       if not style.Get('BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF'):
         pytree_utils.SetNodeAnnotation(first_token.node,
                                        pytree_utils.Annotation.NEWLINES, None)
